@@ -16,7 +16,7 @@ alfa.rda <- function(xnew, x, ina, a, gam = 1, del = 0) {
   ## gam*Spooled+(1-gam)*diagonal
   ## del is between QDA and LDA
   ## del*QDa+(1-del)*LDA
-  y <- alfa(x, a)$aff  ## apply the alpha-transformation
-  ynew <- alfa(xnew, a)$aff
-  rda(xnew = ynew, x = y, ina = ina, gam = gam, del = del)
+  y <- Compositional::alfa(x, a)$aff  ## apply the alpha-transformation
+  ynew <- Compositional::alfa(xnew, a)$aff
+  Compositional::rda(xnew = ynew, x = y, ina = ina, gam = gam, del = del)
 }
