@@ -17,10 +17,8 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
     zz <- mu1^a
     ta <- rowSums(zz)
     za <- zz / ta
-    za <- D / a * za - 1/a
-    ma <- za %*% ha
-    esa <- ya - ma
-    sa <- crossprod(esa)
+    ma <- ( D / a * za - 1/a ) %*% ha
+    sa <- crossprod(ya - ma)
     log( det(sa) )
   }
 
@@ -28,14 +26,14 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
   d <- D - 1  ## dimensionality of the simplex
   dm <- dim(x)
   p <- dm[2]  ;    n <- dm[1]
-  
+
   if ( is.null(yb) ) {
-    ya <- alfa(y, a)$aff
+    ya <- Compositional::alfa(y, a)$aff
   } else  ya <- yb
   x <- model.matrix(ya ~., data.frame(x) )
 
   if ( a == 0 ) {
-    mod <- comp.reg(y, x[, -1], yb = yb)
+    mod <- Compositional::comp.reg(y, x[, -1], yb = yb)
     be <- mod$be
     seb <- mod$seb
     runtime <- mod$runtime
@@ -45,24 +43,27 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
 
     ha <- t( helm(D) )
     ini <- as.vector( solve(crossprod(x), crossprod(x, ya) ) )
-    qa <- nlminb( ini, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(iter.max = 2000) )
-    qa <- optim( qa$par, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(maxit = 5000) )
-    qa <- optim( qa$par, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(maxit = 5000) )
-    qa <- optim( qa$par, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(maxit = 5000), hessian = TRUE )
-    be <- matrix(qa$par, ncol = d)
+    qa1 <- nlminb( ini, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(iter.max = 2000) )
+    qa1 <- optim( qa1$par, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(maxit = 5000) )
+    qa2 <- optim( qa1$par, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(maxit = 5000) )
+    while (qa1$value - qa2$value > 1e-05) {
+      qa1 <- qa2
+      qa2 <- optim( qa1$par, reg, ya = ya, x = x, ha = ha, d = d, n = n, D = D, control = list(maxit = 5000), hessian = TRUE )
+    }
+    be <- matrix(qa2$par, ncol = d)
     runtime <- proc.time() - runtime
-   
+
     if ( seb ) {
-      seb <- sqrt( diag( Rfast::spdinv(qa$hessian) ) )
+      seb <- sqrt( diag( Rfast::spdinv(qa2$hessian) ) )
       seb <- matrix(seb, ncol = d)
     } else  seb <- NULL
   }  ## end if (a == 0)
- 
+
   est <- NULL
   if ( !is.null(xnew) ) {
     xnew <- model.matrix(~., data.frame(xnew) )
     est <- cbind( 1, exp(xnew %*% be) )
-	est <- est/Rfast::rowsums(est)
+	  est <- est/Rfast::rowsums(est)
   }
 
   if ( is.null( colnames(x) ) ) {
