@@ -31,7 +31,7 @@ hotel1T2 <- function(x, M, a = 0.05, R = 999, graph = FALSE) {
     ## bootstrap calibration
     tb <- numeric(R)
     mm <-  - m + M
-    y <- x + rep( mm, rep(n, p) ) ## brings the data
+    y <- Rfast::eachrow(x, mm, oper = "+") ## brings the data
     ## under the null hypothesis, i.e. mean vector equal to M
     for (i in 1:R) {
       b <- sample(1:n, n, replace = TRUE)
